From 729c6355b534cdb28494cdfe7ca3ecd9fc689abb Mon Sep 17 00:00:00 2001
From: patrick-motsch
Date: Sun, 15 Feb 2026 12:20:58 +0100
Subject: [PATCH] fix: increase bot HTTP timeout to 60s for auth flow
Co-authored-by: Cursor
---
modules/features/teamsbot/browserBotConnector.py | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/modules/features/teamsbot/browserBotConnector.py b/modules/features/teamsbot/browserBotConnector.py
index b48280cd..210f09f1 100644
--- a/modules/features/teamsbot/browserBotConnector.py
+++ b/modules/features/teamsbot/browserBotConnector.py
@@ -14,8 +14,8 @@ from typing import Optional, Dict, Any, Callable, Awaitable
logger = logging.getLogger(__name__)
-# Default timeout for bot HTTP calls
-_BOT_TIMEOUT = aiohttp.ClientTimeout(total=30)
+# Default timeout for bot HTTP calls (60s to allow for Microsoft auth flow)
+_BOT_TIMEOUT = aiohttp.ClientTimeout(total=60)
class BrowserBotConnector: